@@ -238,7 +238,7 @@ class MagicBoxApi(object):
                          version: int,
                          is_queued=False):
         return self.__dobotlink.MagicBox.SetColorSensor(portName=port_name,
-                                                        port=port,
+                                                        port=port-1,
                                                         enable=enable,
                                                         version=version,
                                                         isQueued=is_queued)
@@ -254,7 +254,7 @@ class MagicBoxApi(object):
                             version: int,
                             is_queued=False):
         return self.__dobotlink.MagicBox.SetInfraredSensor(portName=port_name,
-                                                           port=port,
+                                                           port=port-1,
                                                            enable=enable,
                                                            version=version,
                                                            isQueued=is_queued)
